# HypEx: Hypotheses and Experiments

[![Telegram](https://img.shields.io/badge/chat-on%20Telegram-2ba2d9.svg)](https://t.me/lamamatcher)

<a name="installation"></a>
# Usage
You can see the examples of usages this addons [here](https://github.com/sb-ai-lab/LightAutoML/blob/master/examples/tutorials/Tutorial_12_Matching.ipynb)
